import { LoadingBarModule, LoadingBarService } from '@ngx-loading-bar/core';
import { Injectable, NgModule } from '@angular/core';
import { HTTP_INTERCEPTORS, HttpClientModule, HttpEventType, HttpResponse } from '@angular/common/http';
import 'rxjs/add/operator/do';

class LoadingBarInterceptor {
    /**
     * @param {?} _loadingBarService
     */
    constructor(_loadingBarService) {
        this._loadingBarService = _loadingBarService;
    }
    /**
     * @param {?} req
     * @param {?} next
     * @return {?}
     */
    intercept(req, next) {
        // https://github.com/angular/angular/issues/18155
        const /** @type {?} */ meta = ((req)).metadata || {};
        if (meta && meta.ignoreLoadingBar === true) {
            return next.handle(req);
        }
        return next.handle(req).do((event) => {
            if (event.type === HttpEventType.Sent) {
                this._loadingBarService.startLoading();
            }
            if (event instanceof HttpResponse) {
                this._loadingBarService.endLoading();
            }
        }, () => this._loadingBarService.endLoading());
    }
}
LoadingBarInterceptor.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
LoadingBarInterceptor.ctorParameters = () => [
    { type: LoadingBarService, },
];

class LoadingBarHttpClientModule {
}
LoadingBarHttpClientModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    HttpClientModule,
                    LoadingBarModule.forRoot(),
                ],
                exports: [
                    HttpClientModule,
                    LoadingBarModule,
                ],
                providers: [
                    { provide: HTTP_INTERCEPTORS, useClass: LoadingBarInterceptor, multi: true },
                ],
            },] },
];
/**
 * @nocollapse
 */
LoadingBarHttpClientModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { LoadingBarHttpClientModule, LoadingBarInterceptor as ɵa };
//# sourceMappingURL=http-client.js.map
